@@ -4,16 +4,22 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 use base qw(Class::Accessor);
-use IO::Socket;
 use Crypt::OpenSSL::X509 qw(FORMAT_ASN1);
 use Date::Parse;
 use DateTime;
 use DateTime::Duration;
 use Time::Duration::Parse;
 
+my $Socket = 'IO::Socket::INET6';
+eval "require $Socket";
+if ($@) {
+    $Socket = 'IO::Socket::INET';
+    require $Socket;
+}
+
 __PACKAGE__->mk_accessors(qw(type target));
 
 my $SSL3_RT_CHANGE_CIPHER_SPEC = 20;
@@ -139,7 +145,8 @@ sub _peer_certificate {
     my $cert;
 
     no warnings 'once';
-    *IO::Socket::INET::write_atomically = sub {
+    no strict 'refs';
+    *{$Socket.'::write_atomically'} = sub {
         my($self, $data) = @_;
 
         my $length    = length $data;
@@ -156,11 +163,13 @@ sub _peer_certificate {
         return $read_byte;
     };
 
-    my $sock = IO::Socket::INET->new(
+    my $sock = {
         PeerAddr => $host,
         PeerPort => $port,
         Proto    => 'tcp',
-       ) or croak "cannot create socket: $!";
+    };
+
+    $sock = $Socket->new( %$sock ) or croak "cannot create socket: $!";
 
     _send_client_hello($sock);
 
@@ -424,13 +433,24 @@ L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-HIROSE Masaaki  C<< <hirose31@gmail.com> >>
+HIROSE Masaaki E<lt>hirose31 _at_ gmail.comE<gt>
 
+=head1 REPOSITORY
 
-=head1 LICENCE AND COPYRIGHT
+L<http://github.com/hirose31/net-ssl-expiredate>
 
-Copyright (c) 2006, HIROSE Masaaki C<< <hirose31@gmail.com> >>. All rights reserved.
+  git clone git://github.com/hirose31/net-ssl-expiredate.git
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+patches and collaborators are welcome.
+
+=head1 SEE ALSO
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright HIROSE Masaaki
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
 
